# w.c.s. - web application for online forms
# Copyright (C) 2005-2010  Entr'ouvert
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

from quixote import redirect
from quixote.directory import Directory
from quixote.html import TemplateIO, htmltext

from wcs.qommon import _, N_
from wcs.qommon import misc
from wcs.categories import Category
from wcs.qommon.form import *
from wcs.qommon.backoffice.menu import html_top
from wcs.qommon.admin.menu import command_icon, error_page
import wcs.admin.categories


class CategoryUI(wcs.admin.categories.CategoryUI):
    def get_form(self, **kwargs):
        form = super().get_form(**kwargs)
        homepage_redirect_url = get_cfg('misc', {}).get('homepage-redirect-url')
        if not homepage_redirect_url:
            form.add(
                SingleSelectWidget,
                'homepage_position',
                title=_('Position on homepage'),
                value=self.category.get_homepage_position(),
                options=[
                    ('1st', _('First Column')),
                    ('2nd', _('Second Column')),
                    ('side', _('Sidebar')),
                    ('none', _('None')),
                ],
            )
            form.add(
                IntWidget,
                'limit',
                title=_('Limit number of items displayed on homepage'),
                value=self.category.get_limit(),
            )
        return form

    def submit_form(self, form):
        super().submit_form(form)

        homepage_redirect_url = get_cfg('misc', {}).get('homepage-redirect-url')
        if not homepage_redirect_url:
            self.category.homepage_position = form.get_widget('homepage_position').parse()
            self.category.limit = form.get_widget('limit').parse()

        self.category.store()


class CategoryPage(wcs.admin.categories.CategoryPage):
    category_ui_class = CategoryUI


class CategoriesDirectory(wcs.admin.categories.CategoriesDirectory):
    label = N_('Categories')
    category_ui_class = CategoryUI
    category_page_class = CategoryPage
